@@ -1,12 +1,10 @@
-import os.path
 from django.conf import settings
-from django.core.exceptions import ImproperlyConfigured
 
 # The directory in which the static files are collected in
 ROOT = getattr(settings, 'STATIC_ROOT', None)
-if ROOT is None:
-    raise ImproperlyConfigured('Please set your STATIC_ROOT setting to an '
-        'existing directory in which the staticfiles can be collected.')
+
+# The URL path to STATIC_ROOT
+URL = getattr(settings, 'STATIC_URL', '')
 
 # A tuple of two-tuples with a name and the path of additional directories
 # which hold static files and should be taken into account
@@ -23,4 +21,8 @@ PREPEND_LABEL_APPS = getattr(settings, 'STATICFILES_PREPEND_LABEL_APPS',
 # Apps that shouldn't be taken into account when collecting app media
 EXCLUDED_APPS = getattr(settings, 'STATICFILES_EXCLUDED_APPS', ())
 
-APPS = [app for app in settings.INSTALLED_APPS if app not in EXCLUDED_APPS]
\ No newline at end of file
+APPS = [app for app in settings.INSTALLED_APPS if app not in EXCLUDED_APPS]
+
+# Destination storage
+STORAGE = getattr(settings, 'STATICFILES_STORAGE',
+                  'staticfiles.storage.StaticFileStorage')
